yazi_macro::mod_flat!(file plugin prework process tasks);

pub const TASKS_BORDER: u16 = 2;
pub const TASKS_PADDING: u16 = 2;
pub const TASKS_PERCENT: u16 = 80;
